glasspy.viscosity package — GlassPy latest documentation

# glasspy.viscosity package

## Submodules

## glasspy.viscosity.diffusion module

Equations for computing the effective diffusion coefficient from viscosity.

glasspy.viscosity.diffusion.diff_coeff_eyring(T, viscosity, diameter)

  Computes the viscosity diffusion coefficient using Eyring equation

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - viscosity – float or array_like with same lenght as T Viscosity at temperature T.

    - diameter – float or array_like with same lenght as T The diameter of the structural unit that is moving due to viscous flow.

  Returns:

    Returns the effective diffusion coefficient computed using the Eyring equation. This equation is similar to the Stokes-Einstein equation, but they were obtained by different routes.

  References

  [1] Eyring, H. (1936). Viscosity, plasticity, and diffusion as examples of

    absolute reaction rates. The Journal of Chemical Physics 4, 283–291.

glasspy.viscosity.diffusion.diff_coeff_stokeseinstein(T, viscosity, diameter)

  Computes the viscosity diffusion coefficient using Stokes-Einstein equation

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - viscosity – float or array_like with same lenght as T Viscosity at temperature T.

    - diameter – float or array_like with same lenght as T The diameter of the structural unit that is moving due to viscous flow.

  Returns:

    Returns the effective diffusion coefficient computed using the Stokes-Einstein equation. This equation is similar to the Eyring equation, but they were obtained by different routes.

  References

  [1] Einstein, A. (1905). On the movement of small particles suspended in

    stationary liquids required by the molecular-kinetic theory of heat. Annalen Der Physik 17, 549–560.

  [2] Einstein, A. (1905). Über die von der molekularkinetischen Theorie der

    Wärme geforderte Bewegung von in ruhenden Flüssigkeiten suspendierten Teilchen. Annalen Der Physik 322, 549–560.

  [3] Stokes, G.G. (1851). On the effect of the internal friction of fluids

    on the motion of pendulums. Transactions of the Cambridge Philosophical Society 9, 8–106.

## glasspy.viscosity.equilibrium module

Equations for equilibrium viscosity.

glasspy.viscosity.equilibrium.ag(T, eta_inf, B, S_conf_fun)

  Computes the viscosity using the Adam & Gibbs equation.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - B – float Adjustable parameter related to the potential energy hindering the cooperative rearrangement per monomer segment.

    - S_conf_fun – callable Function that computes the configurational entropy. This function accepts one argument, which is the absolute temperature.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  References

  [1] Adam, G., and Gibbs, J.H. (1965). On the temperature dependence of

    cooperative relaxation properties in glass-forming liquids. The Journal of Chemical Physics 43, 139–146.

glasspy.viscosity.equilibrium.am(T, eta_inf, alpha, beta)

  Computes the viscosity using the Avramov & Milchev equation.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - alpha – float Adjustable parameter, see original reference. Unitless.

    - beta – float Adjustable parameter with unit of Kelvin.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  References

  [1] Avramov, I., and Milchev, A. (1988). Effect of disorder on diffusion

    and viscosity in condensed systems. Journal of Non-Crystalline Solids 104, 253–260.

  [2] Cornelissen, J., and Waterman, H.I. (1955). The viscosity temperature

    relationship of liquids. Chemical Engineering Science 4, 238–246.

glasspy.viscosity.equilibrium.am_alt(T, eta_inf, T12, m)

  Computes the viscosity using the Avramov & Milchev equation.

  This is the rewriten AM equation found in ref. [3].

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - T12 – float Temperature were the viscosity is 10**12 Pa.s. Unit: Kelvin.

    - m – float Fragility index as defined by Angell, see ref. [4]. Unitless.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  References

  [1] Avramov, I., and Milchev, A. (1988). Effect of disorder on diffusion

    and viscosity in condensed systems. Journal of Non-Crystalline Solids 104, 253–260.

  [2] Cornelissen, J., and Waterman, H.I. (1955). The viscosity temperature

    relationship of liquids. Chemical Engineering Science 4, 238–246.

  [3] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [4] Angell, C.A. (1985). Strong and fragile liquids. In Relaxation in

    Complex Systems, K.L. Ngai, and G.B. Wright, eds. (Springfield: Naval Research Laboratory), pp. 3–12.

glasspy.viscosity.equilibrium.myega(T, eta_inf, K, C)

  Computes the viscosity using the MYEGA equation.

  Mathematicaly, this equation is the same as that proposed in ref. [2] (see page 250), however the physical considerations are different.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - K – float See the original reference for the meaning. Unit: Kelvin.

    - C – float See the original reference for the meaning. Unit: Kelvin.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  Notes

  In the original reference the equation is in base-10 logarithm, see Eq. (6) in [1].

  References

  [1] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [2] Waterton, S.C. (1932). The viscosity-temperature relationship and some

    inferences on the nature of molten and of plastic glass. J Soc Glass Technol 16, 244–249.

glasspy.viscosity.equilibrium.myega_alt(T, eta_inf, T12, m)

  Computes the viscosity using the MYEGA equation.

  This is an alternate form of the MYEGA equation found in [1]

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - T12 – float Temperature were the viscosity is 10**12 Pa.s. Unit: Kelvin.

    - m – float Fragility index as defined by Angell, see ref. [2]. Unitless.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  References

  [1] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [2] Angell, C.A. (1985). Strong and fragile liquids. In Relaxation in

    Complex Systems, K.L. Ngai, and G.B. Wright, eds. (Springfield: Naval Research Laboratory), pp. 3–12.

glasspy.viscosity.equilibrium.vft(T, eta_inf, A, T0)

  Computes the viscosity using the empirical Vogel-Fulcher-Tammann eq.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - A – float Adjustable parameter inside the exponential. Unit: Kelvin.

    - T0 – float Divergence temperature. Unit: Kelvin.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  References

  [1] Vogel, H. (1921). Das Temperatureabhängigketsgesetz der Viskosität von

    Flüssigkeiten. Physikalische Zeitschrift 22, 645–646.

  [2] Fulcher, G.S. (1925). Analysis of recent measurements of the viscosity

    of glasses. Journal of the American Ceramic Society 8, 339–355.

  [3] Tammann, G., and Hesse, W. (1926). Die Abhängigkeit der Viscosität von

    der Temperatur bie unterkühlten Flüssigkeiten. Z. Anorg. Allg. Chem. 156, 245–257.

glasspy.viscosity.equilibrium.vft_alt(T, eta_inf, T12, m)

  Computes the viscosity using the Vogel-Fulcher-Tammann eq.

  This is the rewriten VFT equation found in ref. [4].

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - T12 – float Temperature were the viscosity is 10**12 Pa.s. Unit: Kelvin.

    - m – float Fragility index as defined by Angell, see ref. [5]. Unitless.

  Returns:

    it is not the logarithm of viscosity.

  Return type:

    Returns the viscosity in the units of eta_inf. Note

  References

  [1] Vogel, H. (1921). Das Temperatureabhängigketsgesetz der Viskosität von

    Flüssigkeiten. Physikalische Zeitschrift 22, 645–646.

  [2] Fulcher, G.S. (1925). Analysis of recent measurements of the viscosity

    of glasses. Journal of the American Ceramic Society 8, 339–355.

  [3] Tammann, G., and Hesse, W. (1926). Die Abhängigkeit der Viscosität von

    der Temperatur bie unterkühlten Flüssigkeiten. Z. Anorg. Allg. Chem. 156, 245–257.

  [4] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [5] Angell, C.A. (1985). Strong and fragile liquids. In Relaxation in

    Complex Systems, K.L. Ngai, and G.B. Wright, eds. (Springfield: Naval Research Laboratory), pp. 3–12.

## glasspy.viscosity.equilibrium_log module

Equations for the base-10 logarithm of equilibrium viscosity.

glasspy.viscosity.equilibrium_log.ag(T, eta_inf, B, S_conf_fun)

  Computes the viscosity using the Adam & Gibbs equation.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - B – float Adjustable parameter related to the potential energy hindering the cooperative rearrangement per monomer segment.

    - S_conf_fun – callable Function that computes the configurational entropy. This function accepts one argument, which is the absolute temperature.

  Returns:

    Returns the base-10 logarithm of viscosity.

  References

  [1] Adam, G., and Gibbs, J.H. (1965). On the temperature dependence of

    cooperative relaxation properties in glass-forming liquids. The Journal of Chemical Physics 43, 139–146.

glasspy.viscosity.equilibrium_log.am(T, log_eta_inf, alpha, beta)

  Computes the viscosity using the Avramov & Milchev equation.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - alpha – float Adjustable parameter, see original reference. Unitless.

    - beta – float Adjustable parameter with unit of Kelvin.

  Returns:

    Returns the base-10 logarithm of viscosity.

  References

  [1] Avramov, I., and Milchev, A. (1988). Effect of disorder on diffusion

    and viscosity in condensed systems. Journal of Non-Crystalline Solids 104, 253–260.

  [2] Cornelissen, J., and Waterman, H.I. (1955). The viscosity temperature

    relationship of liquids. Chemical Engineering Science 4, 238–246.

glasspy.viscosity.equilibrium_log.am_alt(T, log_eta_inf, T12, m)

  Computes the viscosity using the Avramov & Milchev equation.

  This is the rewriten AM equation found in ref. [3].

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - T12 – float Temperature were the viscosity is 10**12 Pa.s. Unit: Kelvin.

    - m – float Fragility index as defined by Angell, see ref. [4]. Unitless.

  Returns:

    Returns the base-10 logarithm of viscosity.

  References

  [1] Avramov, I., and Milchev, A. (1988). Effect of disorder on diffusion

    and viscosity in condensed systems. Journal of Non-Crystalline Solids 104, 253–260.

  [2] Cornelissen, J., and Waterman, H.I. (1955). The viscosity temperature

    relationship of liquids. Chemical Engineering Science 4, 238–246.

  [3] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [4] Angell, C.A. (1985). Strong and fragile liquids. In Relaxation in

    Complex Systems, K.L. Ngai, and G.B. Wright, eds. (Springfield: Naval Research Laboratory), pp. 3–12.

glasspy.viscosity.equilibrium_log.myega(T, log_eta_inf, K, C)

  Computes the viscosity using the MYEGA equation.

  Mathematicaly, this equation is the same as that proposed in ref. [2] (see page 250), however the physical considerations are different.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - K – float See the original reference for the meaning. Unit: Kelvin.

    - C – float See the original reference for the meaning. Unit: Kelvin.

  Returns:

    Returns the base-10 logarithm of viscosity.

  Notes

  In the original reference the equation is in base-10 logarithm, see Eq. (6) in [1].

  References

  [1] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [2] Waterton, S.C. (1932). The viscosity-temperature relationship and some

    inferences on the nature of molten and of plastic glass. J Soc Glass Technol 16, 244–249.

glasspy.viscosity.equilibrium_log.myega_alt(T, log_eta_inf, T12, m)

  Computes the viscosity using the MYEGA equation.

  This is an alternate form of the MYEGA equation found in [1]

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - T12 – float Temperature were the viscosity is 10**12 Pa.s. Unit: Kelvin.

    - m – float Fragility index as defined by Angell, see ref. [2]. Unitless.

  Returns:

    Returns the base-10 logarithm of viscosity.

  References

  [1] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [2] Angell, C.A. (1985). Strong and fragile liquids. In Relaxation in

    Complex Systems, K.L. Ngai, and G.B. Wright, eds. (Springfield: Naval Research Laboratory), pp. 3–12.

glasspy.viscosity.equilibrium_log.vft(T, log_eta_inf, A, T0)

  Computes the viscosity using the empirical Vogel-Fulcher-Tammann eq.

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - A – float Adjustable parameter inside the exponential. Unit: Kelvin.

    - T0 – float Divergence temperature. Unit: Kelvin.

  Returns:

    Returns the base-10 logarithm of viscosity.

  References

  [1] Vogel, H. (1921). Das Temperatureabhängigketsgesetz der Viskosität von

    Flüssigkeiten. Physikalische Zeitschrift 22, 645–646.

  [2] Fulcher, G.S. (1925). Analysis of recent measurements of the viscosity

    of glasses. Journal of the American Ceramic Society 8, 339–355.

  [3] Tammann, G., and Hesse, W. (1926). Die Abhängigkeit der Viscosität von

    der Temperatur bie unterkühlten Flüssigkeiten. Z. Anorg. Allg. Chem. 156, 245–257.

glasspy.viscosity.equilibrium_log.vft_alt(T, log_eta_inf, T12, m)

  Computes the viscosity using the Vogel-Fulcher-Tammann eq.

  This is the rewriten VFT equation found in ref. [4].

  Parameters:

    - T – float or array_like Temperature. Unit: Kelvin.

    - eta_inf – float Asymptotic viscosity at the limit of infinite temperature.

    - T12 – float Temperature were the viscosity is 10**12 Pa.s. Unit: Kelvin.

    - m – float Fragility index as defined by Angell, see ref. [5]. Unitless.

  Returns:

    Returns the base-10 logarithm of viscosity.

  References

  [1] Vogel, H. (1921). Das Temperatureabhängigketsgesetz der Viskosität von

    Flüssigkeiten. Physikalische Zeitschrift 22, 645–646.

  [2] Fulcher, G.S. (1925). Analysis of recent measurements of the viscosity

    of glasses. Journal of the American Ceramic Society 8, 339–355.

  [3] Tammann, G., and Hesse, W. (1926). Die Abhängigkeit der Viscosität von

    der Temperatur bie unterkühlten Flüssigkeiten. Z. Anorg. Allg. Chem. 156, 245–257.

  [4] Mauro, J.C., Yue, Y., Ellison, A.J., Gupta, P.K., and Allan, D.C.

    (2009). Viscosity of glass-forming liquids. Proceedings of the National Academy of Sciences of the United States of America 106, 19780–19784.

  [5] Angell, C.A. (1985). Strong and fragile liquids. In Relaxation in

    Complex Systems, K.L. Ngai, and G.B. Wright, eds. (Springfield: Naval Research Laboratory), pp. 3–12.

## Module contents